#!/usr/bin/env node
'use strict';

require('module-alias/register');
const commander = require('commander');

require('../lib/api/model').createCommand(commander);
require('../lib/api/skill').createCommand(commander);
require('../lib/api/vendor').createCommand(commander);
require('../lib/api/account-linking').createCommand(commander);
require('../lib/api/skill-publishing').createCommand(commander);
require('../lib/api/credentials').createCommand(commander);
require('../lib/api/skill-testing').createCommand(commander);
require('../lib/api/skill-validation').createCommand(commander);
require('../lib/api/private-skills').createCommand(commander);
require('../lib/api/enablement').createCommand(commander);
require('../lib/api/in-skill-product').createCommand(commander);
require('../lib/api/utterance-data').createCommand(commander);
require('../lib/api/catalog').createCommand(commander);
require('../lib/api/model-catalog').createCommand(commander);
require('../lib/api/beta-test').createCommand(commander);
require('../lib/api/skill-accuracy').createCommand(commander);
require('../lib/api/hosted-skill').createCommand(commander);

commander
    .usage('\n\n  $ ask api [command]')
    .description('The api command provides a number of subcommands that enable you to create and modify skills associated with your developer account. There are subcommands for creating and updating the skill, interaction model, managing the in-skill products and account linking information as well as starting the skill certification process.')
    .parse(process.argv);

if (!process.argv.slice(2).length) {
    commander.outputHelp();
} else {
    const API_COMMAND_LIST = [
        'create-model-catalog',
        'create-model-catalog-version',
        'update-model-catalog-version',
        'update-model-catalog',
        'get-model-catalog-version',
        'get-model-catalog',
        'list-model-catalogs',
        'list-model-catalog-versions',
        'get-model-catalog-values',
        'get-model-catalog-update-status',
        'delete-model-catalog',
        'delete-model-catalog-version',
        'validate-skill',
        'get-validation',
        'simulate-skill',
        'get-simulation',
        'invoke-skill',
        'create-skill',
        'get-skill',
        'get-alexa-hosted-skill',
        'update-skill',
        'delete-skill',
        'get-model',
        'head-model',
        'update-model',
        'list-model-versions',
        'get-skill-status',
        'get-skill-credentials',
        'get-git-credentials',
        'get-alexa-hosted-skill-permission',
        'create-account-linking',
        'get-account-linking',
        'delete-account-linking',
        'list-skills',
        'list-vendors',
        'submit',
        'withdraw',
        'list-certifications',
        'get-certification',
        'add-private-distribution-account',
        'delete-private-distribution-account',
        'list-private-distribution-accounts',
        'enable-skill',
        'disable-skill',
        'get-skill-enablement',
        'create-isp',
        'get-isp',
        'update-isp',
        'associate-isp',
        'disassociate-isp',
        'list-isp-for-vendor',
        'list-isp-for-skill',
        'list-skills-for-isp',
        'delete-isp',
        'reset-isp-entitlement',
        'intent-requests-history',
        'list-catalogs',
        'create-catalog',
        'get-catalog',
        'list-catalog-uploads',
        'get-catalog-upload',
        'associate-catalog-with-skill',
        'upload-catalog',
        'create-beta-test',
        'update-beta-test',
        'get-beta-test',
        'start-beta-test',
        'end-beta-test',
        'list-beta-testers',
        'add-beta-testers',
        'remove-beta-testers',
        'send-reminder-to-beta-testers',
        'request-feedback-from-beta-testers',
        'nlu-profile',
        'get-conflict-detection-job-status',
        'get-conflicts',
        'evaluate-nlu',
        'list-nlu-evaluations',
        'get-nlu-evaluation',
        'get-nlu-evaluation-results',
        'create-nlu-annotation-set',
        'delete-nlu-annotation-set',
        'get-nlu-annotation-set-annotations',
        'get-nlu-annotation-set-properties',
        'list-nlu-annotation-sets',
        'update-nlu-annotation-set-annotations',
        'update-nlu-annotation-set-properties'
    ];
    if (API_COMMAND_LIST.indexOf(process.argv[2]) === -1) {
        console.log('Command not recognized. Please run "ask api" for help.');
    }
}
