const inquirer = require('inquirer');
const CONSTANTS = require('@src/utils/constants');

module.exports = {
    getSkillName,
    getRunTime,
    getAutoClone,
    getConfirmation,
};

function getSkillName(skillName, callback) {
    if (skillName) {
        process.nextTick(() => {
            callback(null, skillName.trim());
        });
    } else {
        inquirer.prompt([{
            message: 'Please type in your skill name: ',
            type: 'input',
            default: 'change me',
            name: 'skillName',
        }]).then((answer) => {
            callback(null, answer.skillName.trim());
        });
    }
}

function getRunTime(runtime, callback) {
    const choices = Object.keys(CONSTANTS.HOSTED_SKILL.RUNTIME);

    if (!runtime) {
        const runTimeChoiceQuestion = {
            type: 'list',
            message: 'Please select the runtime',
            name: 'runTime',
            choices,
        };
        inquirer.prompt([runTimeChoiceQuestion]).then((answer) => {
            callback(null, answer.runTime.trim());
        });
        return;
    }

    process.nextTick(() => {
        if (choices.includes(runtime)) {
            callback(null, runtime);
        } else {
            callback('[Error]: Invalid runtime. Please run "ask create-hosted-skill -h" for help.', null);
        }
    });
}

function getAutoClone(autoClone, callback) {
    if (autoClone) {
        callback(null, autoClone === 'true');
    } else {
        const confirm = {
            type: 'confirm',
            name: 'isAllowed',
            message: 'Alexa hosted skill is created. Do you want to clone the skill project to current working directory?',
        };
        inquirer.prompt(confirm).then((answers) => {
            callback(null, answers.isAllowed);
        });
    }
}

function getConfirmation(callback) {
    const confirmationQuestion = {
        message: 'Have you completed the captcha validation?',
        type: 'confirm',
        name: 'confirmation',
        default: false
    };
    inquirer.prompt([confirmationQuestion]).then((answer) => {
        callback(answer.confirmation);
    });
}
