const R = require('ramda');

module.exports = {
    isNonEmptyString,
    isNonBlankString,
    isLambdaFunctionName,
    hasDiffContent
};

function isNonEmptyString(str) {
    return R.is(String, str) && !R.isEmpty(str);
}

function isNonBlankString(str) {
    return isNonEmptyString(str) && !!str.trim();
}

/**
 * Check if input string is a valid lambda function name
 * @param {string} str
 */
function isLambdaFunctionName(str) {
    if (!isNonBlankString(str)) {
        return false;
    }

    // This regex can be used to check if the str
    // could be a valid lambda function name
    const lambdaFunctionNameRegex = /^([a-zA-Z0-9-_]+)$/;
    return lambdaFunctionNameRegex.test(str);
}

/**
 * Check if the input string is a meaningful diff result or only contains header message
 */
function hasDiffContent(str) {
    if (!isNonBlankString(str)) {
        return false;
    }

    const lines = str.split(/\r\n|\n/);

    // Exclude the case when string only contains three lines of headers (diff example shown as below):
    // ===================================================================
    // --- local  {filename}
    // +++ remote {filename}
    // (new line)
    if (lines.length <= 4) {
        return false;
    }

    // Exclude when there is no line starting with "-" or "+"
    for (const line of lines) {
        if ((line.startsWith('-') && !line.startsWith('---'))
        || (line.startsWith('+') && !line.startsWith('+++'))) {
            return true;
        }
    }
    return false;
}