'use strict';

const expect = require('chai').expect;
const stringUtils = require('@src/utils/string-utils');


describe('Utils test - string utility', () => {
    describe('# test function isNonEmptyString', () => {
        [
            {
                testCase: 'input is an object',
                str: {},
                expectation: false
            },
            {
                testCase: 'input is an array',
                str: [1, 2, 3],
                expectation: false
            },
            {
                testCase: 'input is a boolean',
                str: true,
                expectation: false
            },
            {
                testCase: 'input is an empty string',
                str: '',
                expectation: false
            },
            {
                testCase: 'input is a blank string',
                str: '      ',
                expectation: true
            },
            {
                testCase: 'input is a string with actual content',
                str: ' test string ',
                expectation: true
            },
        ].forEach(({ testCase, str, expectation }) => {
            it(`| ${testCase}, expect isNonEmptyString ${expectation}`, () => {
                // call
                const callResult = stringUtils.isNonEmptyString(str);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });

    describe('# test function isNonBlankString', () => {
        [
            {
                testCase: 'input is an object',
                str: {},
                expectation: false
            },
            {
                testCase: 'input is an array',
                str: [1, 2, 3],
                expectation: false
            },
            {
                testCase: 'input is a boolean',
                str: true,
                expectation: false
            },
            {
                testCase: 'input is an empty string',
                str: '',
                expectation: false
            },
            {
                testCase: 'input is a blank string',
                str: '      ',
                expectation: false
            },
            {
                testCase: 'input is a string with actual content',
                str: ' test string ',
                expectation: true
            },
        ].forEach(({ testCase, str, expectation }) => {
            it(`| ${testCase}, expect isNonBlankString ${expectation}`, () => {
                // call
                const callResult = stringUtils.isNonBlankString(str);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });

    describe('# test function isLambdaFunctionName', () => {
        [
            {
                testCase: 'input is an object',
                str: {},
                expectation: false
            },
            {
                testCase: 'input is an array',
                str: [1, 2, 3],
                expectation: false
            },
            {
                testCase: 'input is a boolean',
                str: true,
                expectation: false
            },,
            {
                testCase: 'input url string is null',
                str: null,
                expectation: false
            },
            {
                testCase: 'input url string is undefined',
                str: undefined,
                expectation: false
            },
            {
                testCase: 'input url string is empty',
                str: '',
                expectation: false
            },
            {
                testCase: 'input url string is blank',
                str: '        ',
                expectation: false
            },
            {
                testCase: 'input url string is valid function name',
                str: 'ask-custom-cityGuide-default',
                expectation: true
            },
            {
                testCase: 'input url string is http',
                str: 'http://lambda.arn.com',
                expectation: false
            },
            {
                testCase: 'input url string is https',
                str: 'https://test.com',
                expectation: false
            },
            {
                testCase: 'input url is random string',
                str: 'abc:A:<http://lambda>/invoke',
                expectation: false
            }

        ].forEach(({ testCase, str, expectation }) => {
            it(`| ${testCase}, expect isLambdaFunctionName ${expectation}`, () => {
                // call
                const callResult = stringUtils.isLambdaFunctionName(str);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });

    describe('# test function hasDiffContent', () => {
        [
            {
                testCase: 'input is an object',
                str: {},
                expectation: false
            },
            {
                testCase: 'input is an array',
                str: [1, 2, 3],
                expectation: false
            },
            {
                testCase: 'input is a boolean',
                str: true,
                expectation: false
            },,
            {
                testCase: 'input string is null',
                str: null,
                expectation: false
            },
            {
                testCase: 'input string is undefined',
                str: undefined,
                expectation: false
            },
            {
                testCase: 'input string is empty',
                str: '',
                expectation: false
            },
            {
                testCase: 'input string is blank',
                str: '        ',
                expectation: false
            },
            {
                testCase: 'input string is not a meaningful diff',
                str: '--- local skill.json\n+++ remote skill.json\n',
                expectation: false
            },
            {
                testCase: 'input string is an empty diff header',
                str: '===================================================================\n--- local skill.json\n+++ remote skill.json\n',
                expectation: false
            },
            {
                testCase: 'input string is substantial diff string',
                str: '===================================================================\n--- local skill.json\n+++ remote skill.json\n@@ -60,5 +60,5 @@\n-}\n+}',
                expectation: true
            },
            {
                testCase: 'input string is diff string without - or +',
                str: '===================================================================\n--- local skill.json\n+++ remote skill.json\n@@ -60,5 +60,5 @@\nrandom\nrandom\nrandom\nrandom\nrandom\nrandom\nrandom\n}\n}',
                expectation: false
            },
            {
                testCase: 'input string is a diff string with - and +',
                str: 'Index: \n===================================================================\n--- \t\n+++ \t\n@@ -1,21 +1,35 @@\n {\n   "manifest": {\n+    "apis": {\n+      "custom": {\n+        "isDialogUsedByLocale": {}\n+      }\n+    },\n+    "manifestVersion": "1.0",\n+    "permissions": [],\n+    "privacyAndCompliance": {\n+      "allowsPurchases": false,\n+      "usesPersonalInfo": false,\n+      "isChildDirected": false,\n+      "isExportCompliant": true,\n+      "containsAds": false\n+    },\n     "publishingInformation": {\n       "locales": {\n         "en-US": {\n+          "name": "How to create skill",\n           "summary": "Spend some time coming up with an interesting, succinct description.",\n+          "description": "Sample Full Description",\n           "examplePhrases": [\n             "Alexa open Minecraft Helper",\n             "Alexa ask Minecraft Helper what\'s the recipe for a chest",\n             "Alexa ask Minecraft Helper how do I get a map"\n           ],\n           "keywords": [\n             "Minecraft",\n             "game"\n-          ],\n-          "name": "How to create skill",\n-          "description": "Sample Full Description"\n+          ]\n         },\n         "de-DE": {\n           "name": "How to create skill"\n         },\n@@ -26,24 +40,7 @@\n       "isAvailableWorldwide": true,\n       "testingInstructions": "Sample Testing Instructions.",\n       "category": "EDUCATION_AND_REFERENCE",\n       "distributionCountries": []\n-    },\n-    "apis": {\n-      "custom": {\n-        "endpoint": {\n-          "sourceDir": "lambda/custom",\n-          "uri": "ask-custom-how-to-create-skill"\n-        }\n-      }\n-    },\n-    "manifestVersion": "1.0",\n-    "permissions": [],\n-    "privacyAndCompliance": {\n-      "allowsPurchases": false,\n-      "isExportCompliant": true,\n-      "containsAds": false,\n-      "isChildDirected": false,\n-      "usesPersonalInfo": false\n     }\n   }\n }\n',
                expectation: true
            }

        ].forEach(({ testCase, str, expectation }) => {
            it(`| ${testCase}, expect hasDiffContent ${expectation}`, () => {
                // call
                const callResult = stringUtils.hasDiffContent(str);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });
});



